@@ -108,15 +108,20 @@
 	       vals)
      ,@(map (lambda (val)
 	      (if (pair? (cddr val))
-		  `(set! (setter ',(car val)) 
-			 (lambda (s v)
-			   (if (not (,(caddr val) v))
-			       (error 'wrong-type-arg "(set! ~S ~S) but ~S is not ~A" s v v ',(caddr val)))
-			   v))
+		  `(set! (setter ',(car val))
+			 (if (not (,(caddr val) ,(car val)))
+			     (error 'wrong-type "initial value ~S is not ~S" ,(car val) ,(caddr val))
+			     (lambda (s v)
+			       (if (not (,(caddr val) v))
+				   (error 'wrong-type-arg "(set! ~S ~S) but ~S is not ~A" s v v ',(caddr val)))
+			       v)))
 		  (values)))
 	    vals)
      ,@body))
 
+(define-macro (typed-inlet . vals) ; vals: ((var init [type])...)...) as in (typed-inlet (i 0 integer?)...)
+  `(typed-let ,vals (curlet)))
+
 
 ;;; ----------------
 (define (first obj)  (if (sequence? obj) (obj 0) (error 'wrong-type-arg "first argument, ~S, is not a sequence" obj)))
@@ -130,6 +135,13 @@
 (define (ninth obj)  (if (sequence? obj) (obj 8) (error 'wrong-type-arg "ninth argument, ~S, is not a sequence" obj)))
 (define (tenth obj)  (if (sequence? obj) (obj 9) (error 'wrong-type-arg "tenth argument, ~S, is not a sequence" obj)))
 
+(define (built-in? x) 
+  (not (undefined? (eval-string (string-append "#_" (object->string x)))))) ; just a guess...
+
+(define (the type expr) 
+  (if (type expr)
+      expr
+      (error 'bad-type "~S is ~S but should be ~S" expr (type-of expr) type)))
 
 (define iota 
   (let ((+documentation+ "(iota n (start 0) (incr 1)) returns a list counting from start for n:\n\
@@ -191,15 +203,7 @@
 	  (copy lis :readable)
 	  lis))))
 
-(define tree-member 
-  (let ((+documentation+ "(tree-member sym tree) returns #t if sym is found anywhere in tree:\n\
-    (tree-member 'a '(1 (2 a))) -> #t"))
-    (lambda (sym tree)
-      (and (pair? tree)
-	   (or (eq? (car tree) sym)
-	       (and (pair? (car tree))
-		    (tree-member sym (car tree)))
-	       (tree-member sym (cdr tree)))))))
+(define tree-member tree-memq)
 
 (define adjoin 
   (let ((+documentation+ "(adjoin obj lst) adds obj to lst if it is not already in lst, returning the new list"))
@@ -1377,10 +1381,12 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 (define (sequence->string val)
   (let ((ctrl-str (cond ((or (not (sequence? val)) 
 			     (empty? val))    "~S")
+			((int-vector? val)    "#i(~{~D~| ~})")
+			((byte-vector? val)   "#u(~{~D~| ~})")
+			((float-vector? val)  "#r(~{~A~| ~})")
 			((vector? val)        "#(~{~A~| ~})")
 			((let? val)           "(inlet ~{'~A~| ~})")
 			((hash-table? val)    "(hash-table ~{'~A~| ~})")
-			((byte-vector? val)   "#u8(~{~D~| ~})")
 			((not (string? val))  "(~{~A~| ~})")
 			(else                 "\"~{~A~|~}\""))))
     (format #f ctrl-str val)))
@@ -1719,6 +1725,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 		 `((lambda* ,(cons ',e ',arg-names)                                ; prepend added env arg because there might be a rest arg
 		     (let ((,',result '?))
 		       (dynamic-wind
+			   (lambda () #f)
 			   (lambda ()                                              ; when function called, show args and caller
 			     (with-let (funclet Display)                           ; indent
 			       (prepend-spaces)
@@ -1729,8 +1736,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 			     (let ((caller (eval '__func__ ,',e)))                 ; show caller 
 			       (if (not (eq? caller #<undefined>))
 				   (format (Display-port) " ;called from ~A" caller)))
-			     (newline (Display-port)))
-			   (lambda ()                                              ; the original function body
+			     (newline (Display-port))
 			     (set! ,',result ,',body))                             ;   but annotated by proc-walk
 			   (lambda ()                                              ; at the end, show the result
 			     (with-let (funclet Display)
@@ -1779,8 +1785,7 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
    :max-stack-size                (*s7* 'max-stack-size)
    :autoloading?                  (*s7* 'autoloading?)
    :undefined-identifier-warnings (*s7* 'undefined-identifier-warnings)
-   :catches                       (*s7* 'catches)
-   :exits                         (*s7* 'exits)))
+   :catches                       (*s7* 'catches)))
 
 
 
@@ -1867,13 +1872,13 @@ Unlike full-find-if, safe-find-if can handle any circularity in the sequences.")
 	   (for-each
 	    (lambda (op) 
 	      (set! (ht op) #t))
-	    '(symbol? gensym? keyword? let? openlet? iterator? macro? c-pointer? c-object? immutable? constant?
+	    '(symbol? gensym? keyword? let? openlet? iterator? macro? c-pointer? c-object? c-object-type immutable? constant?
 	      input-port? output-port? eof-object? integer? number? real? complex? rational? random-state? 
 	      char? string? list? pair? vector? float-vector? int-vector? byte-vector? hash-table? 
 	      continuation? procedure? dilambda? boolean? float? proper-list? sequence? null? gensym 
 	      symbol->string string->keyword symbol->keyword byte-vector-ref byte-vector-set!
 	      inlet sublet coverlet openlet let-ref let-set! make-iterator iterate iterator-sequence
-	      iterator-at-end? provided? provide c-pointer port-line-number port-filename 
+	      iterator-at-end? provided? provide c-pointer c-pointer-type c-pointer-info port-line-number port-filename 
 	      pair-line-number pair-filename port-closed? let->list char-ready? flush-output-port 
 	      open-input-string open-output-string get-output-string quasiquote call-with-values multiple-value-bind
 	      newline write display read-char peek-char write-char write-string read-byte write-byte 
