@@ -4,21 +4,24 @@
 ;;;    "alloc-lines" is any number bigger than the number of lines in "file"
 ;;;    (dups 16 "s7.c" 89000) finds all 16-line matches in s7.c which has less than 89000 lines in all
 
+(set! (*s7* 'heap-size) (* 2 1024000))
+
 (define dups 
   (let ()
 
     (define-constant (all-positive? v start end)
-      (let ((j end))
-	(do ((i start (+ i 1)))
-	    ((= i end) j)
-	  (if (< (int-vector-ref v i) 0)
-	      (set! j i)))))
+      (do ((j (- end 1) (- j 1)))
+	  ((or (negative? (int-vector-ref v j))
+	       (= j start))
+	   (if (= j start)
+	       end
+	       j))))
 
     (lambda (size file alloc-lines)
       (let ((lines (make-vector alloc-lines ""))
 	    (original-lines (make-vector alloc-lines ""))
-	    (lens (make-int-vector alloc-lines 0))
-	    (linenums (make-int-vector alloc-lines 0)))
+	    (lens (make-int-vector alloc-lines))
+	    (linenums (make-int-vector alloc-lines)))
 	
 	(call-with-input-file file
 	  (lambda (p)
@@ -44,16 +47,17 @@
 			   (do ((j (- len 1) (- j 1)))
 			       ((or (< j 0)
 				    (not (char-whitespace? (string-ref line j))))
-				(when (not (= j (- len 1)))
+				(unless (= j (- len 1))
 				  (set! line (substring line 0 (+ j 1)))
-				  (set! len (+ j 1))))))
-			 (when (> len 0)
-			   (int-vector-set! linenums j i)
-			   (vector-set! lines j line)
-			   (int-vector-set! lens j (length line))
-			   (set! j (+ j 1))))))))
+				  (set! len (+ j 1)))))
+			   (when (> len 0)
+			     (int-vector-set! linenums j i)
+			     (vector-set! lines j line)
+			     (int-vector-set! lens j (length line))
+			     (set! j (+ j 1)))))))))
 	      
 	      (set! size (min size total-lines))
+	      ;; (format *stderr* "lines: ~S~%" total-lines)
 
 	      ;; mark unmatchable strings
 	      (let ((sortv (make-vector total-lines)))
@@ -73,20 +77,22 @@
 			     (int-vector-set! lens (cdr (vector-ref sortv i)) unctr)
 			     (set! unctr (- unctr 1)))
 			   (set! i k)))))))
-	      
+
 	      ;; look for matches
 	      (do ((i 0 (+ i 1))
 		   (first #t #t)
 		   (last-line (- total-lines size)))
 		  ((>= i last-line)) ; >= because i is set below
 		(let ((j (all-positive? lens i (+ i size))))   ; is a match possible?
-		  (if (= j (+ i size))
+		  (if (not (= j (+ i size)))
+		      (set! i j)
 		      (let ((lenseq (subvector lens size i))
 			    (lineseq (subvector lines size i)))
 			(do ((k (+ i 1) (+ k 1)))
 			    ((>= k last-line))
 			  (let ((jk (all-positive? lens k (+ k size))))
-			    (if (= jk (+ k size))
+			    (if (not (= jk (+ k size)))
+				(set! k jk)
 				(when (and (equal? lenseq (subvector lens size k))
 					   (equal? lineseq (subvector lines size k)))
 				  (let ((full-size size))
@@ -95,7 +101,7 @@
 					((or (= nk total-lines)
 					     (not (= (int-vector-ref lens ni) (int-vector-ref lens nk)))
 					     (not (string=? (vector-ref lines ni) (vector-ref lines nk))))
-					 (set! full-size (+ size (- nk jk)))))
+					 (set! full-size (- (+ size nk) jk))))
 				    (if first
 					(let ((first-line (int-vector-ref linenums i)))
 					  (format *stderr* "~NC~%~{~A~%~}~%  lines ~D ~D" 8 #\- ; lineseq 
@@ -106,13 +112,11 @@
 					(format *stderr* " ~D" (int-vector-ref linenums k)))
 				    (set! i (+ i full-size))
 				    (when (< size full-size)
-				      (format *stderr* "[~D]" full-size))))
-				(set! k jk))))
+				      (format *stderr* "[~D]" full-size)))))))
 			(unless first
-			  (format *stderr* "~%")))
-		      (set! i j)))))))))))
+			  (format *stderr* "~%")))))))))))))
 
-(dups 16 "s7.c" 89000)
-;(dups 6 "s7.c" 89000)
+(dups 16 "s7.c" 91000)
+;(dups 6 "s7.c" 91000)
 ;(dups 12 "ffitest.c" 2000)
 ;(dups 8 "ffitest.c" 2000)
