@@ -84,6 +84,7 @@ static s7_pointer dax_to_string(s7_scheme *sc, s7_pointer args)
   data_str_len = strlen(data_str);
   str = (char *)calloc(data_str_len + 32, sizeof(char));
   snprintf(str, data_str_len + 32, "#<dax %.3f %s>", o->x, data_str);
+  free(data_str);
   result = s7_make_string(sc, str);
   free(str);
   return(result);
@@ -814,8 +815,11 @@ int main(int argc, char **argv)
   s7_set_default_random_state(sc, 1234, 5678);
   s7_random(sc, NULL);
   s7_stacktrace(sc);
+
   if (s7_list(sc, 0) != s7_nil(sc))
     fprintf(stderr, "s7_list 0 is not ()\n");
+  if (s7_list_nl(sc, 0, NULL) != s7_nil(sc))
+    fprintf(stderr, "s7_list_nl 0 is not ()\n");
 
   p = s7_make_vector(sc, 12);
   gc_loc = s7_gc_protect(sc, p);
@@ -906,6 +910,15 @@ int main(int argc, char **argv)
   
   s7_gc_unprotect_at(sc, gc_loc);
 
+  p = s7_list_nl(sc, 3, TO_S7_INT(1), TO_S7_INT(2), TO_S7_INT(3), NULL);
+  gc_loc = s7_gc_protect(sc, p);
+  if (!s7_is_list(sc, p))
+    {fprintf(stderr, "%d: %s is not a list?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
+  if (s7_list_length(sc, p) != 3)
+    {fprintf(stderr, "%d: (length %s) is not 3?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
+  if (s7_integer(s7_list_ref(sc, p, 1)) != 2)
+    {fprintf(stderr, "%d: (%s 1) is not 2?\n", __LINE__, s1 = TO_STR(p)); free(s1);}
+  s7_gc_unprotect_at(sc, gc_loc);
 
   {
     s7_pointer c1, c2, c3, c12, c23, c123, c1234, c1d2, c2d3, c3d4, c12d3, c23d4, c123d4, c1234d5;
