@@ -14,12 +14,15 @@
 		     ;("lg.scm" . "v-lg")
 		     ("titer.scm" . "v-iter")
 		     ("tsort.scm" . "v-sort")
+		     ("tlet.scm" . "v-let")
 		     ("thash.scm" . "v-hash")
 		     ("tgen.scm" . "v-gen")
 		     ("tall.scm" . "v-all")
 		     ("snd-test.scm" . "v-call")
 		     ("dup.scm" . "v-dup")
 		     ("tset.scm" . "v-set")
+		     ("trec.scm" . "v-rec")
+		     ("tclo.scm" . "v-clo")
 		     ))
 
 (define (last-callg)
@@ -70,13 +73,16 @@
 	 (list "repl" "tform.scm")
 	 (list "repl" "tfft.scm")
 	 (list "repl" "tmap.scm")
+	 (list "repl" "tlet.scm")
 	 (list "repl" "titer.scm")
 	 (list "repl" "tsort.scm")
+	 (list "repl" "tclo.scm")
 	 ;(list "repl" "lg.scm")
 	 (list "repl" "thash.scm")
-	 (list "repl" "tset.scm")
 	 (list "repl" "dup.scm")
+	 (list "repl" "tset.scm")
 	 (list "snd -noinit" "tgen.scm")    ; repl here + cload sndlib was slower
+	 (list "repl" "trec.scm")
 	 (list "snd -noinit" "tall.scm")
 	 (list "snd -l" "snd-test.scm")
 	 )))
